ProSHADE: Class Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - r -

- readInMAP() : ProSHADE_internal_data::ProSHADE_data
- readInPDB() : ProSHADE_internal_data::ProSHADE_data
- readInStructure() : ProSHADE_internal_data::ProSHADE_data
- reBoxMap : ProSHADE_settings
- recommendedSymmetryFold : ProSHADE_settings
- recommendedSymmetryType : ProSHADE_settings
- removePhaseInormation() : ProSHADE_internal_data::ProSHADE_data
- removeSmallPeaks() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- removeWaters : ProSHADE_settings
- reportOverlayResults() : ProSHADE_internal_data::ProSHADE_data
- reportSymmetryResults() : ProSHADE_internal_data::ProSHADE_data
- requestedResolution : ProSHADE_settings
- requestedSymmetryFold : ProSHADE_settings
- requestedSymmetryType : ProSHADE_settings
- reSampleMap() : ProSHADE_internal_data::ProSHADE_data
- rotateMap() : ProSHADE_internal_data::ProSHADE_data
- rotationUncertainty : ProSHADE_settings
- rotSphericalHarmonics : ProSHADE_internal_data::ProSHADE_data
- rotTrsJSONFile : ProSHADE_settings
- rrpMatrices : ProSHADE_internal_data::ProSHADE_data